You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@kylin.apache.org by li...@apache.org on 2015/03/03 10:59:16 UTC

[12/23] incubator-kylin git commit: minor change

minor change


Project: http://git-wip-us.apache.org/repos/asf/incubator-kylin/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-kylin/commit/17e96686
Tree: http://git-wip-us.apache.org/repos/asf/incubator-kylin/tree/17e96686
Diff: http://git-wip-us.apache.org/repos/asf/incubator-kylin/diff/17e96686

Branch: refs/heads/master
Commit: 17e966860cf3a1b7b9bf86dc0ac3a36465eac25a
Parents: 6c84f5a
Author: honma <ho...@ebay.com>
Authored: Wed Feb 11 14:10:47 2015 +0800
Committer: honma <ho...@ebay.com>
Committed: Wed Feb 11 14:10:47 2015 +0800

----------------------------------------------------------------------
 pom.xml           | 2 +-
 sandbox_deploy.sh | 4 ++--
 2 files changed, 3 insertions(+), 3 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-kylin/blob/17e96686/pom.xml
----------------------------------------------------------------------
diff --git a/pom.xml b/pom.xml
index caa3ee6..8494497 100644
--- a/pom.xml
+++ b/pom.xml
@@ -524,7 +524,7 @@
                             <excludes>
                                 <exclude>**/com/kylinolap/job/**</exclude>
                                 <exclude>**/BuildCubeWithEngineTest.java</exclude>
-                                <exclude>**/SampleCubeSetupTest.java</exclude>
+                                <exclude>**/SampleCubeSetupAsTest.java</exclude>
                                 <exclude>**/InvertedIndexHBaseTest.java</exclude>
                                 <exclude>**/StorageTest.java</exclude>
                                 <exclude>**/KylinQueryTest.java</exclude>

http://git-wip-us.apache.org/repos/asf/incubator-kylin/blob/17e96686/sandbox_deploy.sh
----------------------------------------------------------------------
diff --git a/sandbox_deploy.sh b/sandbox_deploy.sh
index 022145f..7e7e8c2 100755
--- a/sandbox_deploy.sh
+++ b/sandbox_deploy.sh
@@ -112,7 +112,7 @@ source ./package.sh
 echo "retrieving classpath..."
 cd $KYLIN_HOME/job/target
 JOB_JAR_NAME="kylin-job-latest.jar"
 #export hbase configs, most of the configurations are useless now, but KYLIN_HBASE_CONF_PATH is used by SampleCubeSetupTest now
 hbase org.apache.hadoop.util.RunJar $JOB_JAR_NAME com.kylinolap.job.deployment.HbaseConfigPrinter /tmp/kylin_retrieve.sh
 #load config variables
 source /tmp/kylin_retrieve.sh
@@ -143,7 +143,7 @@ cat examples/test_case_data/sandbox/kylin_job_conf.xml > /etc/kylin/kylin_job_co
 # 1. generate synthetic fact table(test_kylin_fact) data and dump it into hive
 # 2. create empty cubes on these data, ready to be built
 cd $KYLIN_HOME
-mvn test -Dtest=com.kylinolap.job.SampleCubeSetupTest -DfailIfNoTests=false
+mvn test -Dtest=com.kylinolap.job.SampleCubeSetupAsTest -DfailIfNoTests=false
 
 #overwrite server.xml
 mv ${CATALINA_HOME}/conf/server.xml ${CATALINA_HOME}/conf/server.xml.bak
@@ -112,7 +112,7 @@ source ./package.sh
 cd $KYLIN_HOME/job/target
 JOB_JAR_NAME="kylin-job-latest.jar"
-#export hbase configs, most of the configurations are useless now, but KYLIN_HBASE_CONF_PATH is used by SampleCubeSetupTest now
+#export hbase configs, most of the configurations are useless now, but KYLIN_HBASE_CONF_PATH is used by SampleCubeSetupAsTest now
 hbase org.apache.hadoop.util.RunJar $JOB_JAR_NAME com.kylinolap.job.deployment.HbaseConfigPrinter /tmp/kylin_retrieve.sh
 #load config variables